document.write('<table width="100%" border="0"><tr>');
document.write('<td><a href="http://logback.qos.ch/">');
document.write('<img src="' + prefix + 'images/logos/lblogo.jpg" alt="" border="0"/>');
document.write('</a></td>')

document.write('<td>&nbsp;</td>');

document.write('</tr></table>')


document.write('<div id="headerLine"></div>');
